//=== File Prolog ============================================================
//
//	This code was developed by NASA, Goddard Space Flight Center, Code 580
//	for the Instrument Remote Control (IRC) project.
//
//--- Notes ------------------------------------------------------------------
//  Development history is located at the end of the file.
//
//--- Warning ----------------------------------------------------------------
//	This software is property of the National Aeronautics and Space
//	Administration. Unauthorized use or duplication of this software is
//	strictly prohibited. Authorized users are subject to the following
//	restrictions:
//	*	Neither the author, their corporation, nor NASA is responsible for
//		any consequence of the use of this software.
//	*	The origin of this software must not be misrepresented either by
//		explicit claim or by omission.
//	*	Altered versions of this software must be plainly marked as such.
//	*	This notice may not be removed or altered.
//
//=== End File Prolog ========================================================

package gov.nasa.gsfc.irc.devices.ports.connections;

/**
 * A ConnectSource is a source of 
 * {@link gov.nasa.gsfc.irc.devices.ports.connections.ConnectEvent ConnectEvents}.
 *
 * <P>This code was developed for NASA, Goddard Space Flight Center, Code 580
 * for the Instrument Remote Control (IRC) project.
 *
 * @version	$Date: 2005/05/04 16:02:33 $
 * @author	tames
 **/
public interface ConnectSource
{
	/**
	 * Registers the given listener for events generated by this
	 * source.
	 * 
	 * @param listener a ConnectListener to register
	 */
	public void addConnectListener(ConnectListener listener);
	
	/**
	 * Unregisters the given listener.
	 * 
	 * @param listener a ConnectListener to unregister
	 */
	public void removeConnectListener(ConnectListener listener);
	
	/**
	 * Gets an array of listeners registered to receive notification
	 * of new ConnectEvents.
	 * 
	 * @return an array of registered ConnectListeners
	 */
	public ConnectListener[] getConnectListeners();
}


//--- Development History  ---------------------------------------------------
//
//  $Log: ConnectSource.java,v $
//  Revision 1.1  2005/05/04 16:02:33  tames_cvs
//  Initial version
//
//