//=== File Prolog ============================================================
//
//	This code was developed by NASA, Goddard Space Flight Center, Code 580
//	for the Instrument Remote Control (IRC) project.
//
//--- Notes ------------------------------------------------------------------
//  Development history is located at the end of the file.
//
//--- Warning ----------------------------------------------------------------
//	This software is property of the National Aeronautics and Space
//	Administration. Unauthorized use or duplication of this software is
//	strictly prohibited. Authorized users are subject to the following
//	restrictions:
//	*	Neither the author, their corporation, nor NASA is responsible for
//		any consequence of the use of this software.
//	*	The origin of this software must not be misrepresented either by
//		explicit claim or by omission.
//	*	Altered versions of this software must be plainly marked as such.
//	*	This notice may not be removed or altered.
//
//=== End File Prolog ========================================================

package gov.nasa.gsfc.irc.devices.ports.connections;

/**
 *  An InputBufferSource is a source of InputBufferEvents.
 *
 * <P>This code was developed for NASA, Goddard Space Flight Center, Code 580
 * for the Instrument Remote Control (IRC) project.
 *
 * @version	$Date: 2005/02/07 05:02:47 $
 * @author 	Troy Ames
 */
public interface InputBufferSource
{
	/**
	 * Registers the given listener for InputBufferEvent objects generated by 
	 * this connection.
	 * 
	 * @param listener a InputBufferListener to register
	 */
	public void addInputBufferListener(InputBufferListener listener);

	/**
	 * Unregisters the given listener.
	 * 
	 * @param listener a InputBufferListener to unregister
	 */
	public void removeInputBufferListener(InputBufferListener listener);

	/**
	 * Gets an array of listeners registered to receive notification
	 * of new InputBufferEvent objects.
	 * 
	 * @return an array of registered InputBufferListeners
	 */
	public InputBufferListener[] getInputBufferListeners();
}


//--- Development History  ---------------------------------------------------
//
//  $Log: InputBufferSource.java,v $
//  Revision 1.1  2005/02/07 05:02:47  tames
//  Initial Version
//
//