//=== File Prolog ============================================================
//
//  $Header: /cvs/IRCv6/Dev/source/core/gov/nasa/gsfc/irc/devices/ports/connections/OutputBufferSource.java,v 1.2 2005/05/04 17:15:04 tames_cvs Exp $
//
//	This code was developed by NASA, Goddard Space Flight Center, Code 580
//	for the Instrument Remote Control (IRC) project.
//
//--- Notes ------------------------------------------------------------------
//  Development history is located at the end of the file.
//
//--- Warning ----------------------------------------------------------------
//	This software is property of the National Aeronautics and Space
//	Administration. Unauthorized use or duplication of this software is
//	strictly prohibited. Authorized users are subject to the following
//	restrictions:
//	*	Neither the author, their corporation, nor NASA is responsible for
//		any consequence of the use of this software.
//	*	The origin of this software must not be misrepresented either by
//		explicit claim or by omission.
//	*	Altered versions of this software must be plainly marked as such.
//	*	This notice may not be removed or altered.
//
//=== End File Prolog ========================================================
package gov.nasa.gsfc.irc.devices.ports.connections;

/**
 *  An OutputBufferSource is a source of OutputBufferEvents.
 *
 *  <P>This code was developed for NASA, Goddard Space Flight Center, Code 580
 *  for the Instrument Remote Control (IRC) project.
 *
 *  @version	$Date: 2005/05/04 17:15:04 $
 *  @author		Troy Ames
 */
public interface OutputBufferSource
{
	/**
	 * Registers the given listener for events generated by this
	 * source.
	 * 
	 * @param listener a OutputBufferListener to register
	 */
	public void addOutputBufferListener(OutputBufferListener listener);

	/**
	 * Unregisters the given listener.
	 * 
	 * @param listener a OutputBufferListener to unregister
	 */
	public void removeOutputBufferListener(OutputBufferListener listener);
	
	/**
	 * Gets an array of listeners registered to receive notification
	 * of new OutputBufferEvents.
	 * 
	 * @return an array of registered OutputBufferListeners
	 */
	public OutputBufferListener[] getOutputBufferListeners();
}

//--- Development History  ---------------------------------------------------
//
//  $Log: OutputBufferSource.java,v $
//  Revision 1.2  2005/05/04 17:15:04  tames_cvs
//  Javadoc update only.
//
//  Revision 1.1  2004/10/14 15:16:51  chostetter_cvs
//  Extensive descriptor-oriented refactoring
//
//  Revision 1.1  2004/10/05 13:50:16  tames_cvs
//  Reflects changes made to the OutputAdapter interface and abstract
//  implementations.
//
//
